/*
 * @Author: wenjie 1454560336@qq.com
 * @Date: 2024-11-14 15:02:58
 * @LastEditors: wenjie 1454560336@qq.com
 * @LastEditTime: 2024-11-25 17:13:07
 * @FilePath: \admin-manage\src\store\modules\user.js
 * @Description: 
 * 
 * Copyright (c) 2024 by ${git_name_email}, All Rights Reserved. 
 */
import { login,getMenuAuth,getAuthButton} from '@/api/auth'
import { getToken, setToken, removeToken,setREToken } from '@/utils/auth'
import { resetRouter, asyncRouter } from '@/router'
import Layout from '@/layout'
import operationLayout from '@/views/operationManage/index'
// import { getMenu } from '@/api/menu'
// import {login} from '@/api/home'
const getDefaultState = () => {
  return {
    token: getToken(),
    refreshToken:'',
    name: '',
    avatar: '',
    menus:null,
    btnAuthObj:{},
  }
}

 

const state = getDefaultState()

const mutations = {
  RESET_STATE: (state) => {
    Object.assign(state, getDefaultState())
  },
  SET_TOKEN: (state, token) => {
    state.token = token
  },
  REFRESH_TOKEN: (state, token) => {
    state.refreshToken = token
  },
  SET_NAME: (state, name) => {
    state.name = name
  },
  SET_AVATAR: (state, avatar) => {
    state.avatar = avatar
  },
  SET_MENU: (state, menus) => {
    state.menus = menus
  },
  SET_BTNAUTH: (state, btnAuthObj) => {
    state.btnAuthObj = btnAuthObj
  }
}

const actions = {
  // user login
  login({ commit }, userInfo) {
    const { account, password,timestamp } = userInfo
    return new Promise((resolve, reject) => {
      login({ account: account.trim(), pwd: password.trim(),timestamp }).then(response => {
        const { content } = response
        if (response.state == 'Success') {
          commit('SET_TOKEN', content.access_token)
          commit('REFRESH_TOKEN', content.refresh_token)
          setToken(content.access_token)
          setREToken(content.refresh_token)
          window.localStorage.setItem('user_type', content.token_type)
          resolve(content)
        }else{
          reject()
        }
      }).catch(error => {
        reject(error)
      })
    })
  },

  // 获取菜单
  getMenu({ commit, state }) {
    return new Promise((resolve, reject) => {
      getMenuAuth({menuSource:1,shopId:0}).then(response => {
        if(response.state == 'Success'){

        let menuList = response.content
        let list = []
        menuList.map(item=>{
          let obj = {}
          obj = {
            path: item.requestUrl,
            component: Layout,
            meta: {
              title: item.menuName,
              icon: 'el-icon-s-shop'
            },
            alwaysShow: item.showStatus == 1?true:false,
            children:[]
          }
          if(item.childs&&item.childs.length>0){
            item.childs.map(subItem=>{
              let subObj = {}
              if(subItem.childs&&subItem.childs.some((item)=>{return item.menuType==2})){

                subObj = {
                  path: subItem.requestUrl,
                  name: subItem.requestUrl,
                  component:operationLayout,
                  meta: {
                    title: subItem.menuName,
                    // icon: 'el-icon-s-shop'
                  },
                  alwaysShow: true,
                  children:[]
                }
                subItem.childs.map(i=>{
                  if(i.menuType==2){
                    subObj.children.push({
                      path:i.requestUrl,
                      name:i.requestUrl,
                      component:resolve => require([`@/views${i.requestUrl}`], resolve),
                      hidden:i.showStatus == 1?false:true,
                      meta: {
                        title: i.menuName,
                      }

                    })
                  }
                })

              }else{
                subObj = {
                  path: subItem.requestUrl,
                  name: subItem.requestUrl,
                  hidden:subItem.showStatus == 1?false:true,
                  component:resolve => require([`@/views${subItem.requestUrl}`], resolve),
                  meta: {
                    title: subItem.menuName,
                  },
                }
              }
              obj.children.push(subObj)
            })
          }
          list.push(obj)

        })
        list.push({ path: '*', redirect: '/404', hidden: true })
        list = asyncRouter.concat(list)
        commit('SET_MENU', list)

          getAuthButton({shopId:0}).then(res=>{
            if(res.state == 'Success'){
                commit('SET_BTNAUTH', res.content)
            }
          })

        resolve(list)
        }
      }).catch(error => {
        reject(error)
      })
    })
  },

  // user logout
  logout({ commit, state }) {
    return new Promise((resolve, reject) => {
        removeToken() // must remove  token  first
        resetRouter()
        window.localStorage.clear()
        commit('RESET_STATE')
        resolve()
    })
  },

  // remove token
  resetToken({ commit }) {
    return new Promise(resolve => {
      removeToken() // must remove  token  first
      commit('RESET_STATE')
      resolve()
    })
  }
}

export default {
  namespaced: true,
  state,
  mutations,
  actions
}

